@@ -92,9 +92,15 @@ av_extend(AV *av, I32 key)
 		U32 bytes;
 #endif
 
+#ifdef MYMALLOC
+		newmax = malloced_size((void*)AvALLOC(av))/sizeof(SV*) - 1;
+
+		if (key <= newmax) 
+		    goto resized;
+#endif 
 		newmax = key + AvMAX(av) / 5;
 	      resize:
-#ifdef STRANGE_MALLOC
+#if defined(STRANGE_MALLOC) || defined(MYMALLOC)
 		Renew(AvALLOC(av),newmax+1, SV*);
 #else
 		bytes = (newmax + 1) * sizeof(SV*);
@@ -114,6 +120,7 @@ av_extend(AV *av, I32 key)
 		    Safefree(AvALLOC(av));
 		AvALLOC(av) = ary;
 #endif
+	      resized:
 		ary = AvALLOC(av) + AvMAX(av) + 1;
 		tmp = newmax - AvMAX(av);
 		if (av == curstack) {	/* Oops, grew stack (via av_store()?) */
@@ -123,7 +130,7 @@ av_extend(AV *av, I32 key)
 		}
 	    }
 	    else {
-		newmax = key < 4 ? 4 : key;
+		newmax = key < 3 ? 3 : key;
 		New(2,AvALLOC(av), newmax+1, SV*);
 		ary = AvALLOC(av) + 1;
 		tmp = newmax;
@@ -327,6 +334,9 @@ av_clear(register AV *av)
 	return;
     /*SUPPRESS 560*/
 
+    if (SvREADONLY(av))
+	croak(no_modify);
+
     /* Give any tie a chance to cleanup first */
     if (SvRMAGICAL(av))
 	mg_clear((SV*)av); 
@@ -756,13 +766,6 @@ avhv_delete_ent(AV *av, SV *keysv, I32 flags, U32 hash)
     return sv;
 }
 
-I32
-avhv_iterinit(AV *av)
-{
-    HV *keys = avhv_keys(av);
-    return hv_iterinit(keys);
-}
-
 HE *
 avhv_iternext(AV *av)
 {
