@@ -115,7 +115,7 @@ $VERSION = "1.02" ;
     sys_stat_h => [qw(S_IRGRP S_IROTH S_IRUSR S_IRWXG S_IRWXO S_IRWXU
 		S_ISBLK S_ISCHR S_ISDIR S_ISFIFO S_ISGID S_ISREG
 		S_ISUID S_IWGRP S_IWOTH S_IWUSR S_IXGRP S_IXOTH S_IXUSR
-		fstat mkfifo)],
+		fstat mkfifo mknod)],
 
     sys_times_h => [qw()],
 
@@ -827,7 +827,14 @@ sub fork {
 sub getcwd
 {
     usage "getcwd()" if @_ != 0;
-    chop($cwd = `pwd`);
+    if ($^O eq 'MSWin32') {
+	# this perhaps applies to everyone else also?
+	require Cwd;
+	$cwd = &Cwd::cwd;
+    }
+    else {
+	chop($cwd = `pwd`);
+    }
     $cwd;
 }
 
