@@ -1,10 +1,13 @@
 case `uname -r` in
 6.1*) shellflags="-m+65536" ;;
 esac
-optimize="-O1"
+case "$optimize" in
+'') optimize="-O1" ;;
+esac
 d_setregid='undef'
 d_setreuid='undef'
 case "$usemymalloc" in
-'') usemymalloc='y' ;;
+'') usemymalloc='y'
+    ccflags="$ccflags -DNO_RCHECK"
+    ;;
 esac
-
