@@ -31,9 +31,6 @@ typedef long long __int64;
 #define __declspec(x)
 #define PERL_GLOBAL_STRUCT
 #define MULTIPLICITY
-#ifndef TLS_OUT_OF_INDEXES
-#define TLS_OUT_OF_INDEXES (DWORD)0xFFFFFFFF
-#endif
 #endif
 
 /* Define DllExport akin to perl's EXT, 
@@ -60,6 +57,10 @@ typedef long long __int64;
 #define  CONTEXT	PERL_CONTEXT	/* Avoid conflict of CONTEXT defs. */
 #endif /*WIN32_LEAN_AND_MEAN */
 
+#ifndef TLS_OUT_OF_INDEXES
+#define TLS_OUT_OF_INDEXES (DWORD)0xFFFFFFFF
+#endif
+
 #include <dirent.h>
 #include <io.h>
 #include <process.h>
@@ -151,6 +152,55 @@ typedef long		uid_t;
 typedef long		gid_t;
 #pragma  warning(disable: 4018 4035 4101 4102 4244 4245 4761)
 
+#ifndef PERL_OBJECT
+
+/* Visual C thinks that a pointer to a member variable is 16 bytes in size. */
+#define STRUCT_MGVTBL_DEFINITION					\
+struct mgvtbl {								\
+    union {								\
+	int	    (CPERLscope(*svt_get))	_((SV *sv, MAGIC* mg));	\
+	char	    handle_VC_problem1[16];				\
+    };									\
+    union {								\
+	int	    (CPERLscope(*svt_set))	_((SV *sv, MAGIC* mg));	\
+	char	    handle_VC_problem2[16];				\
+    };									\
+    union {								\
+	U32	    (CPERLscope(*svt_len))	_((SV *sv, MAGIC* mg));	\
+	char	    handle_VC_problem3[16];				\
+    };									\
+    union {								\
+	int	    (CPERLscope(*svt_clear))	_((SV *sv, MAGIC* mg));	\
+	char	    handle_VC_problem4[16];				\
+    };									\
+    union {								\
+	int	    (CPERLscope(*svt_free))	_((SV *sv, MAGIC* mg));	\
+	char	    handle_VC_problem5[16];				\
+    };									\
+}
+
+#define BASEOP_DEFINITION		\
+    OP*		op_next;		\
+    OP*		op_sibling;		\
+    OP*		(CPERLscope(*op_ppaddr))_((ARGSproto));		\
+    char	handle_VC_problem[12];	\
+    PADOFFSET	op_targ;		\
+    OPCODE	op_type;		\
+    U16		op_seq;			\
+    U8		op_flags;		\
+    U8		op_private;
+
+#define UNION_ANY_DEFINITION union any {		\
+    void*	any_ptr;				\
+    I32		any_i32;				\
+    IV		any_iv;					\
+    long	any_long;				\
+    void	(CPERLscope(*any_dptr)) _((void*));	\
+    char	handle_VC_problem[16];			\
+}
+
+#endif /* PERL_OBJECT */
+
 #endif /* _MSC_VER */
 
 #ifdef __MINGW32__		/* Minimal Gnu-Win32 */
